==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/fr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tâches",
    "Due yesterday" : "Pour hier",
    "Due today" : "Pour aujourd'hui",
    "Due tomorrow" : "Pour demain",
    "Due on" : "Échéance",
    "Started yesterday" : "Débutées hier",
    "Starts today" : "Débute aujourd'hui",
    "Starts tomorrow" : "Débute demain",
    "Started on" : "Débuté le",
    "Starts on" : "Débute le",
    "[Remind me yesterday at ]HH:mm" : "[Rappel hier à ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Rappel aujourd'hui à ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Rappel demain à ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Rappel le ]MMM DD, YYYY,[ à ]HH:mm",
    "Yesterday" : "Hier",
    "Today" : "Aujourd'hui",
    "Tomorrow" : "Demain",
    "in %s" : "dans %s",
    "%s ago" : "il y a %s",
    "seconds" : "secondes",
    "a minute" : "une minute",
    "%d minutes" : "%d minutes",
    "an hour" : "une heure",
    "%d hours" : "%d heures",
    "a day" : "un jour",
    "%d days" : "%d jours",
    "a month" : "un mois",
    "%d months" : "%d mois",
    "a year" : "un an",
    "%d years" : "%d ans",
    "week" : "semaine",
    "weeks" : "semaines",
    "day" : "jour",
    "days" : "jours",
    "hour" : "heure",
    "hours" : "heures",
    "minute" : "minute",
    "minutes" : "minutes",
    "second" : "seconde",
    "before beginning" : "avant le début",
    "after beginning" : "après le début",
    "before end" : "avant la fin",
    "after end" : "après la fin",
    "Comment" : "Commenter",
    "Add a comment" : "Ajouter un commentaire",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ceci va supprimer le Calendrier \"%s\" et tout son contenu.",
    "The name \"%s\" is already used." : "Le nom \"%s\" est déjà utilisé.",
    "An empty name is not allowed." : "Un nom vide n'est pas autorisé.",
    "Hidden" : "Masqué",
    "Visible" : "Visible",
    "Automatic" : "Automatique",
    "Sunday" : "Dimanche",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Add an important item in \"%s\"..." : "Ajouter un élément important dans \"%s\"...",
    "Add an item due today in \"%s\"..." : "Ajouter un élément échéant aujourd'hui dans \"%s\"...",
    "Add an item in \"%s\"..." : "Ajouter un élément dans \"%s\"...",
    "Add a current item in \"%s\"..." : "Ajouter un élément courant dans \"%s\"...",
    "Add a subtask to \"%s\"..." : "Ajouter une sous-tâche à \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tâche terminée","%n tâches terminées"],
    "Hours" : "Heures",
    "Minutes" : "Minutes",
    "Set due date" : "Spécifier la date d'échéance",
    "%s %% completed" : "complétée à %s %%",
    "priority %s: " : "priorité %s :",
    "high" : "haute",
    "medium" : "moyenne",
    "low" : "basse",
    "no priority assigned" : "aucune priorité assignée",
    "Remind me" : "Rappel",
    "at the end" : "à la fin",
    "at the beginning" : "au début",
    "Set start date" : "Spécifier la date de début",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Unnamed" : "Sans nom",
    "Important" : "Important",
    "Week" : "Cette semaine",
    "All" : "Tout",
    "Current" : "En ce moment",
    "Completed" : "Terminé",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "Edit" : "Modifier",
    "Link" : "Lien",
    "Download" : "Télécharger",
    "Save" : "Enregistrer",
    "Add List..." : "Ajouter une liste...",
    "New List" : "Nouvelle liste",
    "Settings" : "Paramètres",
    "Start of week" : "Début de semaine",
    "Visibility of Smart Collections" : "Visibilité des collections Smart",
    "Change sort order" : "Modifier l'ordre de tri",
    "Default" : "Défaut",
    "Due date" : "Date d'échéance",
    "Start date" : "Date de début",
    "Priority" : "Priorité",
    "Alphabetically" : "Par ordre alphabétique",
    "Manually" : "Manuellement",
    "Load remaining completed tasks." : "Charger le reste des tâches terminées.",
    "All day" : "Tous les jours",
    "(New category)" : "(Nouvelle catégorie)",
    "Select categories..." : "Sélectionner des catégories…",
    "Loading the task..." : "Chargement de la tâche…",
    "Task not found!" : "Tâche non trouvée !",
    "add a subtask to" : "ajouter une sous-tâche à"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/fr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tâches",
    "Due yesterday" : "Pour hier",
    "Due today" : "Pour aujourd'hui",
    "Due tomorrow" : "Pour demain",
    "Due on" : "Échéance",
    "Started yesterday" : "Débutées hier",
    "Starts today" : "Débute aujourd'hui",
    "Starts tomorrow" : "Débute demain",
    "Started on" : "Débuté le",
    "Starts on" : "Débute le",
    "[Remind me yesterday at ]HH:mm" : "[Rappel hier à ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Rappel aujourd'hui à ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Rappel demain à ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Rappel le ]MMM DD, YYYY,[ à ]HH:mm",
    "Yesterday" : "Hier",
    "Today" : "Aujourd'hui",
    "Tomorrow" : "Demain",
    "in %s" : "dans %s",
    "%s ago" : "il y a %s",
    "seconds" : "secondes",
    "a minute" : "une minute",
    "%d minutes" : "%d minutes",
    "an hour" : "une heure",
    "%d hours" : "%d heures",
    "a day" : "un jour",
    "%d days" : "%d jours",
    "a month" : "un mois",
    "%d months" : "%d mois",
    "a year" : "un an",
    "%d years" : "%d ans",
    "week" : "semaine",
    "weeks" : "semaines",
    "day" : "jour",
    "days" : "jours",
    "hour" : "heure",
    "hours" : "heures",
    "minute" : "minute",
    "minutes" : "minutes",
    "second" : "seconde",
    "before beginning" : "avant le début",
    "after beginning" : "après le début",
    "before end" : "avant la fin",
    "after end" : "après la fin",
    "Comment" : "Commenter",
    "Add a comment" : "Ajouter un commentaire",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ceci va supprimer le Calendrier \"%s\" et tout son contenu.",
    "The name \"%s\" is already used." : "Le nom \"%s\" est déjà utilisé.",
    "An empty name is not allowed." : "Un nom vide n'est pas autorisé.",
    "Hidden" : "Masqué",
    "Visible" : "Visible",
    "Automatic" : "Automatique",
    "Sunday" : "Dimanche",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Add an important item in \"%s\"..." : "Ajouter un élément important dans \"%s\"...",
    "Add an item due today in \"%s\"..." : "Ajouter un élément échéant aujourd'hui dans \"%s\"...",
    "Add an item in \"%s\"..." : "Ajouter un élément dans \"%s\"...",
    "Add a current item in \"%s\"..." : "Ajouter un élément courant dans \"%s\"...",
    "Add a subtask to \"%s\"..." : "Ajouter une sous-tâche à \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n tâche terminée","%n tâches terminées"],
    "Hours" : "Heures",
    "Minutes" : "Minutes",
    "Set due date" : "Spécifier la date d'échéance",
    "%s %% completed" : "complétée à %s %%",
    "priority %s: " : "priorité %s :",
    "high" : "haute",
    "medium" : "moyenne",
    "low" : "basse",
    "no priority assigned" : "aucune priorité assignée",
    "Remind me" : "Rappel",
    "at the end" : "à la fin",
    "at the beginning" : "au début",
    "Set start date" : "Spécifier la date de début",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Unnamed" : "Sans nom",
    "Important" : "Important",
    "Week" : "Cette semaine",
    "All" : "Tout",
    "Current" : "En ce moment",
    "Completed" : "Terminé",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "Edit" : "Modifier",
    "Link" : "Lien",
    "Download" : "Télécharger",
    "Save" : "Enregistrer",
    "Add List..." : "Ajouter une liste...",
    "New List" : "Nouvelle liste",
    "Settings" : "Paramètres",
    "Start of week" : "Début de semaine",
    "Visibility of Smart Collections" : "Visibilité des collections Smart",
    "Change sort order" : "Modifier l'ordre de tri",
    "Default" : "Défaut",
    "Due date" : "Date d'échéance",
    "Start date" : "Date de début",
    "Priority" : "Priorité",
    "Alphabetically" : "Par ordre alphabétique",
    "Manually" : "Manuellement",
    "Load remaining completed tasks." : "Charger le reste des tâches terminées.",
    "Task is completed" : "La tâche est terminée",
    "All day" : "Tous les jours",
    "(New category)" : "(Nouvelle catégorie)",
    "Select categories..." : "Sélectionner des catégories…",
    "Loading the task..." : "Chargement de la tâche…",
    "Task not found!" : "Tâche non trouvée !",
    "add a subtask to" : "ajouter une sous-tâche à",
    "Toggle subtasks" : "Activer / Désactiver les sous-tâches",
    "Toggle completed subtasks" : "Activer / Désactiver les sous-tâches terminées"
},
"nplurals=2; plural=(n > 1);");
